'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var path = require('path');
var spawn = require('cross-spawn');
var rimraf = require('rimraf');
var yargsParser = require('yargs-parser');

var _require = require('../../utils'),
    hasFile = _require.hasFile,
    resolveBin = _require.resolveBin,
    fromRoot = _require.fromRoot,
    getConcurrentlyArgs = _require.getConcurrentlyArgs;

var crossEnv = resolveBin('cross-env');
var rollup = resolveBin('rollup');
var args = process.argv.slice(2);
var here = function here(p) {
  return path.join(__dirname, p);
};
var parsedArgs = yargsParser(args);

var useBuiltinConfig = !args.includes('--config') && !hasFile('rollup.config.js');
var config = useBuiltinConfig ? `--config ${here('../../config/rollup.config.js')}` : args.includes('--config') ? '' : '--config'; // --config will pick up the rollup.config.js file

var environment = parsedArgs.environment ? `--environment ${parsedArgs.environment}` : '';
var watch = parsedArgs.watch ? '--watch' : '';

var formats = ['esm', 'cjs', 'umd', 'umd.min'];

if (typeof parsedArgs.bundle === 'string') {
  formats = parsedArgs.bundle.split(',');
}

var defaultEnv = 'BUILD_ROLLUP=true';

var getCommand = function getCommand(env) {
  return [crossEnv, defaultEnv, env, rollup, config, environment, watch].filter(Boolean).join(' ');
};

var scripts = args.includes('--p-react') ? getPReactScripts() : getConcurrentlyArgs(getCommands());

rimraf.sync(fromRoot('dist'));

var result = spawn.sync(resolveBin('concurrently'), scripts, {
  stdio: 'inherit'
});

function getPReactScripts() {
  var reactCommands = prefixKeys('react.', getCommands());
  var preactCommands = prefixKeys('preact.', getCommands('BUILD_PREACT=true'));
  return getConcurrentlyArgs(Object.assign(reactCommands, preactCommands));
}

function prefixKeys(prefix, object) {
  return Object.entries(object).reduce(function (cmds, _ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    cmds[`${prefix}${key}`] = value;
    return cmds;
  }, {});
}

function getCommands() {
  var env = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  return formats.reduce(function (cmds, format) {
    var _format$split = format.split('.'),
        _format$split2 = _slicedToArray(_format$split, 2),
        formatName = _format$split2[0],
        _format$split2$ = _format$split2[1],
        minify = _format$split2$ === undefined ? false : _format$split2$;

    cmds[format] = getCommand(`BUILD_FORMAT=${formatName} BUILD_MINIFY=${Boolean(minify)} ${env}`);
    return cmds;
  }, {});
}

process.exit(result.status);