'use strict';

var fs = require('fs');
var path = require('path');
var spawn = require('cross-spawn');

var _require = require('../utils'),
    fromRoot = _require.fromRoot;

var _require2 = require('../utils'),
    hasPkgProp = _require2.hasPkgProp,
    resolveBin = _require2.resolveBin;

var args = process.argv.slice(2);

var here = function here(p) {
  return path.join(__dirname, p);
};

var useBuiltinConfig = !args.includes('--config') && !fs.existsSync(fromRoot('.prettierrc')) && !hasPkgProp('prettierrc');
var config = useBuiltinConfig ? ['--config', here('../config/prettierrc.js')] : [];

var useBuiltinIgnore = !args.includes('--ignore-path') && !fs.existsSync(fromRoot('.prettierignore'));
var ignore = useBuiltinIgnore ? ['--ignore-path', here('../config/prettierignore')] : [];

var write = args.includes('--no-write') ? [] : ['--write'];

// this ensures that when running format as a pre-commit hook and we get
// the full file path, we make that non-absolute so it is treated as a glob,
// This way the prettierignore will be applied
var relativeArgs = args.map(function (a) {
  return a.replace(`${process.cwd()}/`, '');
});

var result = spawn.sync(resolveBin('prettier'), [].concat(config, ignore, write).concat(relativeArgs), { stdio: 'inherit' });

process.exit(result.status);